@@ -5,11 +5,13 @@ import simplemma
 from googletrans import Translator
 import requests
 from bs4 import BeautifulSoup
+from bidict import bidict
+from .db import *
 translator = Translator()
-
+dictdb = LocalDictionary()
 langdata = simplemma.load_data('en')
 
-code = {
+code = bidict({
     "English": "en",
     "Chinese": "zh",
     "Italian": "it",
@@ -29,7 +31,7 @@ code = {
     "Korean": "ko",
     "Arabic": "ar",
     "Turkish": "tr",
-}
+})
 
 wikt_languages = code.keys()
 gdict_languages = ['en', 'hi', 'es', 'fr', 'ja', 'ru', 'de', 'it', 'ko', 'ar', 'tr', 'pt']
@@ -38,7 +40,7 @@ simplemma_languages = ['bg', 'ca', 'cy', 'da', 'de', 'en', 'es', 'et', 'fa', 'fi
                        'lv', 'nl', 'pt', 'ro', 'ru', 'sk', 'sl', 'sv', 'tr', 'uk', 'ur']
 dictionaries = {"Wiktionary (English)": "wikt-en",
                 "Google dictionary (Monolingual)": "gdict",
-                "Google translate (To English)": "gtrans"}
+                "Google translate": "gtrans"}
 
 
 def removeAccents(word):
@@ -73,13 +75,25 @@ def removeAccents(word):
 
 def fmt_result(definitions):
     "Format the result of dictionary lookup"
-    print("fmt result called")
     lines = []
     for defn in definitions:
         lines.append("<i>" + defn['pos'] + "</i>")
         lines.extend([str(item[0]+1) + ". " + item[1] for item in list(enumerate(definitions[0]['meaning']))])
     return "<br>".join(lines)
 
+def lem_word(word, language):
+    """Lemmatize a word. We will use simplemma, and if that
+    isn't supported either, we give up."""
+    if language in simplemma_languages:
+        global langdata
+        if langdata[0][0] != language:
+            langdata = simplemma.load_data(language)
+            return lem_word(word, language)
+        else:
+            return simplemma.lemmatize(word, langdata)
+    else:
+        return word
+
 def wiktionary(word, language, lemmatize=True):
     "Get definitions from Wiktionary"
     try:
@@ -110,18 +124,6 @@ def wiktionary(word, language, lemmatize=True):
         definitions.append(meaning_item)
     return {"word": word, "definition": definitions}
 
-def lem_word(word, language):
-    """Lemmatize a word. We will use simplemma, and if that
-    isn't supported either, we give up."""
-    if language in simplemma_languages:
-        global langdata
-        if langdata[0][0] != language:
-            langdata = simplemma.load_data(language)
-            return lem_word(word, language)
-        else:
-            return simplemma.lemmatize(word, langdata)
-
-
 def googledict(word, language, lemmatize=True):
     """Google dictionary lookup. Note Google dictionary cannot provide
     lemmatization, so only Russian is supported through PyMorphy2."""
@@ -148,27 +150,35 @@ def googledict(word, language, lemmatize=True):
         definitions.append(meaning_item)
     return {"word": word, "definition": definitions}
 
-def googletranslate(word, language):
+def googletranslate(word, language, gtrans_lang):
     "Google translation, through the googletrans python library"
-    #print(translator.translate(word, src=language).text)
-    return {"word": word, "definition": translator.translate(word, src=language).text}
+    return {"word": word, "definition": translator.translate(word, src=language, dest=gtrans_lang).text}
 
 
-def lookupin(word, language, lemmatize=True, dictionary="Wiktionary (English)"):
-    print("Using", dictionary)
-    word = word
+def lookupin(word, language, lemmatize=True, dictionary="Wiktionary (English)", gtrans_lang="English"):
     if lemmatize:
         word = lem_word(word, language)
 
-    dictid = dictionaries[dictionary]
-    if dictid == "gtrans":
-        return googletranslate(word, language)
+    dictid = dictionaries.get(dictionary)
     if dictid == "wikt-en":
         item = wiktionary(word, language, lemmatize)
+        item['definition'] = fmt_result(item['definition'])
         #print(item)
     elif dictid == "gdict":
         item = googledict(word, language, lemmatize)
-        #print(item)
-    item['definition'] = fmt_result(item['definition'])
+        item['definition'] = fmt_result(item['definition'])
+    elif dictid == "gtrans":
+        return googletranslate(word, language, gtrans_lang)
+    else:
+        return {"word": word, "definition": dictdb.define(word, language, dictionary)}
+
     #print(item)
     return item
+
+def getDictsForLang(lang: str):
+    "Get the list of dictionaries for a given language"
+    results = ["Wiktionary (English)", "Google translate"]
+    if lang in gdict_languages:
+        results.append("Google dictionary (Monolingual)")
+    results.extend(dictdb.getNamesForLang(lang))
+    return results
\ No newline at end of file
